#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
from __future__ import with_statement
from trytond.model import ModelSQL, ModelView, ModelSingleton, fields
from trytond.pyson import Eval, If


__all__ = ['VoucherConfiguration', 'VoucherSequence']


class VoucherConfiguration(ModelSingleton, ModelSQL, ModelView):
    'Voucher Configuration'
    __name__ = 'account.voucher_configuration'
    company = fields.Many2One('company.company', 'Company', required=True,
            domain=[
                ('id', If(Eval('context', {}).contains('company'), '=', '!='),
                    Eval('context', {}).get('company', 0)),
                ])
    default_bank_payment = fields.Many2One('bank', 'Default Bank Payment')
    default_bank_receipt = fields.Many2One('bank', 'Default Bank Receipt')
    default_journal_note = fields.Many2One('account.journal', 'Default Journal Note')

    @classmethod
    def __setup__(cls):
        super(VoucherConfiguration, cls).__setup__()


class VoucherSequence(ModelSingleton, ModelSQL, ModelView):
    'Voucher Sequence'
    __name__ = 'account.voucher.sequence'
    voucher_receipt_sequence = fields.Property(fields.Many2One('ir.sequence',
        'Voucher Receipt Sequence', required=True,
        domain=[('code', '=', 'account.voucher')]))
    voucher_payment_sequence = fields.Property(fields.Many2One('ir.sequence',
        'Voucher Payment Sequence', required=True,
        domain=[('code', '=', 'account.voucher')]))
    voucher_notes_sequence = fields.Property(fields.Many2One('ir.sequence',
        'Voucher Notes Sequence', required=True,
        domain=[('code', '=', 'account.voucher')]))
